@@ -21,21 +21,10 @@
 class EndpointData():
 	def __init__(self):
 		self.endpoint_map = {
-			"rus-west-1-pop": "dysmsapi.ap-southeast-1.aliyuncs.com",
 			"cn-beijing": "dysmsapi-proxy.cn-beijing.aliyuncs.com",
-			"ap-south-1": "dysmsapi.ap-southeast-1.aliyuncs.com",
-			"eu-west-1": "dysmsapi.ap-southeast-1.aliyuncs.com",
-			"eu-west-1-oxs": "dysmsapi.ap-southeast-1.aliyuncs.com",
-			"ap-northeast-1": "dysmsapi.ap-southeast-1.aliyuncs.com",
-			"me-east-1": "dysmsapi.ap-southeast-1.aliyuncs.com",
+			"cn-hongkong": "dysmsapi-xman.cn-hongkong.aliyuncs.com",
 			"ap-southeast-1": "dysmsapi.ap-southeast-1.aliyuncs.com",
-			"ap-southeast-2": "dysmsapi.ap-southeast-1.aliyuncs.com",
-			"ap-southeast-3": "dysmsapi.ap-southeast-1.aliyuncs.com",
-			"eu-central-1": "dysmsapi.ap-southeast-1.aliyuncs.com",
-			"ap-southeast-5": "dysmsapi.ap-southeast-1.aliyuncs.com",
-			"us-east-1": "dysmsapi.ap-southeast-1.aliyuncs.com",
-			"ap-northeast-2-pop": "dysmsapi.ap-southeast-1.aliyuncs.com",
-			"us-west-1": "dysmsapi.ap-southeast-1.aliyuncs.com",
+			"ap-southeast-5": "dysmsapi-xman.ap-southeast-5.aliyuncs.com",
 		}
 		self.endpoint_regional = "central"
 
